#
# spec file for package baobab
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2011 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define glib2_version 2.44

Name:           baobab
Version:        47.0
Release:        1.1
Summary:        Disk Usage Analyzer
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Apps/DiskUsageAnalyzer
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.38.0.11
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gio-2.0) >= %{glib2_version}
BuildRequires:  pkgconfig(glib-2.0) >= %{glib2_version}
BuildRequires:  pkgconfig(gobject-2.0) >= %{glib2_version}
BuildRequires:  pkgconfig(gtk4) >= 4.4.0
BuildRequires:  pkgconfig(libadwaita-1) >= 1.6.alpha

%description
Disk Usage Analyzer is a graphical, menu-driven application to analyse
disk usage in any GNOME environment. Disk Usage Analyzer can easily
scan either the whole filesystem tree, or a specific user-requested
directory branch (local or remote).

It also auto-detects in real-time any changes made to your home
directory as far as any mounted/unmounted device. Disk Usage Analyzer
also provides a full graphical treemap window for each selected folder.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc AUTHORS NEWS README.md
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/applications/org.gnome.%{name}.desktop
%{_datadir}/dbus-1/services/org.gnome.baobab.service
%{_datadir}/glib-2.0/schemas/org.gnome.baobab.gschema.xml
%{_datadir}/icons/hicolor/
%{_datadir}/metainfo/org.gnome.baobab.appdata.xml
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Sep 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Port to AdwSpinner.
  + Updated translations.
* Mon Aug 26 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.alpha:
  + Use GtkColumnView instead of GtkTreeView
  + Replace named colors with CSS variables
  + Use symbolic icons in location lists
  + Port to AdwDialog
  + Use AdwPreferencesPage/Group for location list
  + Use AdwButtonRow for "Add Location" button
  + Miscellaneous style cleanups
  + Allow removing files that don't exist
  + New pathbar style
  + Updated translations.
* Fri Mar 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Improved App metainfo.
  + Use enter instead of leave to update highlightitem.
  + Updated translations.
* Wed Jan 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix versioned BuildRequires for libadwaita; according to
  meson.build it must be >= 1.4.alpha.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to source service for easier updating.
* Mon Sep 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Use new libadwaita widgets and design patterns.
  + Updated translations.
* Fri Jul  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Use new libadwaita widgets and design patterns.
  + Updated translations.
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Change "Open Folder" to "Open Externally".
  + Allow activating the menu by pressing the F10 key.
  + Misc string changes.
  + Updated translations.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Updated translations.
* Thu Feb 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Change "Open Folder" to "Open Externally".
  + Allow activating the menu by pressing the F10 key.
  + Misc string changes.
  + Updated translations.
- Add desktop-file-utils BuildRequires: New dependency.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Sun Sep  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.rc:
  + Updated translations.
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Updated translations.
* Mon Jul 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Updated translations.
* Mon Mar 21 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 42.0:
  + Updated translations.
* Tue Mar  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Updated translations.
* Wed Feb 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Updated translations.
* Wed Jan 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha:
  + Ported to GTK4 and libadwaita.
  + Adjusted styling, so that numbers in cells are aligned, keeping
    the UI from shifting during scanning.
  + Updated translations.
- Change BuildRequires according to the GTK4 port:
  + Replace pkgconfig(gtk+-3.0) with pkgconfig(gtk4)
  + Replace pkgconfig(libhandy-1) with pkgconfig(libadwaita-1)
* Tue Sep 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Updated translations.
* Sun Mar 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + Disk Usage Analyzer's visuals have been updated to match the
    GNOME 40 visual style.
  + Updated translations.
- New build requirement: pkgconfig(libhandy-1).
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Added UI to change excluded locations.
  + Style fixes.
- Changes from version 3.37.2:
  + Improved treeview navigation in order to avoid horizontal
    scrolling.
  + Updated color palette of the charts.
  + Added a command line option to cross filesystem boundaries.
- Changes from version 3.35.1:
  + Files are now shown in the UI.
  + Many fixes for the location list, including duplication issues
    and a problem with network locations blocking the UI.
  + Disk Usage Analyzer now shows up in the list of recommended
    applications for folders.
  + Mount points are now excluded only if on different filesystems.
  + Visual fixes (tooltips, sorting of recent items).
  + Added the possibility to clear the recent list.
  + Improved Shortcut window.
  + Updated translations.
- Drop pkgconfig(gio-unix-2.0) BuildRequires: no longer checked in
  meson.build.
* Sun Jun 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Backported bugfixes (network locations blocking the UI).
  + Updated translations.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Minor tweaks for app icon.
  + Updated translations.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + Use new icon design.
  + Add flatpak manifest.
  + Show a notification when scan is complete.
  + Remove the application menu.
  + Add Keyboard Shortcuts window and improve shortcuts.
  + Updated translations.
* Sun Sep  9 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
- Remove lang package from recommended packages as it already
  supplements main package (same effect, it's redundant).
* Thu Jul 26 2018 bjorn.lie@gmail.com
- Update to version 3.29.1:
  + Localization fixes.
  + Updated translations.
- Drop baobab-fix-linguas-build-issues.patch and
  baobab-fix-gschema-translations.patch: Fixed upstream.
- Use autosetup macro.
* Thu Jul 26 2018 bjorn.lie@gmail.com
- Add baobab-fix-gschema-translations.patch: build: Fix gschema
  translations.
* Thu Mar 22 2018 bjorn.lie@gmail.com
- Drop gnome-utils Conflicts, not needed for a long time.
- Drop update-desktop-files BuildRequires and no longer pass
  suse_update_desktop_file macro.
- Add baobab-fix-linguas-build-issues.patch: build: Fix setting
  GNOMELOCALEDIR (bgo#794381), and build: Use LINGUAS file for help
  (bgo#794449).
- Update URL to new home in GNOME wiki.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb 14 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + build: Use python3 found by meson to run
    build-aux/post-install.py (bgo#791980).
  + Updated translations.
* Sun Dec 17 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Add support for mouse back button.
  * Replace window menu with a "Scan" button (and other visual
    tweaks).
  * Minor bugfixes.
  * Updated documentation translations.
  * Updated translations.
- Update Url to https://wiki.gnome.org/Apps/Baobab: current
  Baobab's web page.
- Add gio-unix-2.0 and gobject-2.0 pkgconfig modules. Note that
  they were being pulled with glib-2.0 module and used already
  since they all live in glib2-devel package.
- Add fdupes BuildRequires and its macro for replacement of
  duplicates by hardlinks under the data directory.
- Drop pkgconfig(gobject-introspection-1.0) BuildRequires: it's no
  longer needed/required anymore.
* Tue Oct 17 2017 badshah400@gmail.com
- Update to version 3.27.1:
  + Build system ported to Meson.
  + Use traditional titlebar on Unity.
  + Updated translations.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
* Tue Oct  3 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Fix saving window size.
  + Updated documentation translations.
  + Updated translations.
- Drop %%glib2_gsettings_schema_*, %%desktop_database_* and
  %%icon_theme_cache_* post/postun macros: functionality now covered
  by file triggers.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Raised minimal vala version.
  + Updated translations.
* Sun Sep  3 2017 zaitor@opensuse.org
- Update to version 3.25.92:
  + Updated documentation translations.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Never show more than 5 recent elements.
  + Do not regenerate .po files automatically.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Updated translations.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Sun Sep 18 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Mon Sep 12 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Stop using intltool.
  + Rejig 'devices and locations' UI.
  + Updated AppData.
  + Misc bugfixes.
  + Updated documentations translations.
  + Updated translations.
- Drop intltool BuildRequires following upstream changes.
* Fri Apr 15 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Apr 11 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated AppData.
  + Updated translations.
* Sun Mar 20 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Sun Feb 28 2016 zaitor@opensuse.org
- Update to version 3.19.1:
  + Updated CSS to recent GTK+ changes.
  + Updated AppData file with tags for GNOME Software.
  + Updated translations.
* Fri Oct  9 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Remove scan-remote action.
  + Updated translations.
* Wed Sep 23 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Temporary fix for 'make distcheck' due to bug in Intltool
    (lp#1117944).
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.90:
  + Remove unused scan-home action.
  + Exclude mounts when scanning recent locations.
  + In Ringchart, always use the correct state when getting colors.
  + Fixes for contex menu.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Ship symbolic variant for application icon.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Wed Feb 18 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Exclude mountpoints when handling commandline arguments.
  + Fix HiDPI issues in the charts.
  + Misc fixes and updates for help pages.
  + Updated translations.
* Tue Oct 14 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fix url in manpage.
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Misc fixes.
  + Updated translations.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Add X-GNOME-Utilities category to .desktop file.
  + Updated translations.
* Wed Jul 23 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Import custom CSS, use icon as resources, various other
    adaptation to GTK+ changes.
  + Visual fixes for the ringschart and the chart switcher.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.1:
  + Use more specific error messages (bgo#686136).
  + Adapt to recent GTK+ changes.
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Make DBus-activatable.
  + Fix a problem at startup with treemap as default chart.
  + Misc bugfixes.
  + Updated translations.
- No longer pass obsolete --disable-scrollkeeper to configure.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Misc bugfixes (make sure to clear the hardlink list before
    rescanning, fix a warning).
  + Updated translations.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Minor UI fixes and updates.
  + Adapt to new Vala.
  + Updated translations.
* Tue Feb  4 2014 zaitor@opensuse.org
- Update to version 3.11.1:
  + Updated help pages.
  + Minor fixes.
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 3.10:
  + Updated translations.
* Mon Sep  2 2013 zaitor@opensuse.org
- Update to version 3.9.91:
  + Add an appdata file for gnome-software.
  + Minor fixes.
  + Updated translations.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Use latest GTK+ features.
  + Show a message when allocated size is not available.
  + Misc build system cleanups.
  + Updated translations.
* Sat Aug  3 2013 zaitor@opensuse.org
- Update to version 3.9.3:
  + Adapt to the latest GTK+ and Vala changes.
  + Misc bugfixes.
  + Updated translations.
* Fri Jul 26 2013 zaitor@opensuse.org
- Update to version 3.9.2:
  + The treeview now shows the last modified time.
  + Always exclude mounts by default.
  + Misc bugfixes.
  + Updated help pages.
  + Updated translations.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Use the latest Gtk and Vala features.
  + Port chart widgets to Vala.
  + Minor bugfixes.
  + Updated translations.
- Add pkgconfig(glib-2.0) BuildRequires: new verified dependency.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Minor bugfixes.
  + Updated translations.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Use the newest libgd to animate tranistion to and from the
    results page.
  + Updated translations.
* Fri Feb 22 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Update to the latest libgd and egglistbox.
  + Add an High Contrast icon.
  + Updated translations.
* Mon Jan 14 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Fix crash in the about dialog.
  + Use a menu button instead of toolbar items.
  + Updated translations.
* Sat Jan 12 2013 dimstar@opensuse.org
- Update to version 3.6.4:
  + Fix crash in scan remote folder (bgo#690037)
  + Updated translations.
* Thu Nov 15 2012 dimstar@opensuse.org
- Update to version 3.6.3:
  + Fix crash in the about dialog.
  + Updated translations.
* Wed Oct 17 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Fix linking error on OpenBSD.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Minor tweaks to the UI.
  + Updated translations.
- Add pkgconfig(gobject-introspection-1.0) BuildRequires: enable
  gobject-introspection.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Updated translations.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Updated translations.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Yet more work on the new user interface
  + Updated translations.
* Thu Aug  2 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + More work on the new user interface
  + Updated translations.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Near-complete rewrite in Vala (with substantial internal
    reorganisation)
  + Completely new user interface concept (with more changes to
    come)
  + Updated translations.
- Add vala BuildRequires: baobab was rewritten in vala.
- Drop pkgconfig(libgtop-2.0) BuildRequires.
- Change pkgconfig(glib-2.0) BuildRequires to pkgconfig(gio-2.0):
  this is in sync with what configure checks for.
* Thu Apr  5 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Fix a problem with chart tooltips
  + Updated translations.
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Sat Mar 24 2012 dimstar@opensuse.org
- Remove hack to find localized help: this has been fixed in
  find-lang.sh.
* Mon Mar 19 2012 zaitor@opensuse.org
- Update to version 3.3.4:
  + Misc bugfixes.
  + Updated translations.
* Fri Mar  9 2012 dimstar@opensuse.org
- Update to version 3.3.3:
  + Misc bugfixes.
  + Updated translations.
* Wed Feb 22 2012 vuntz@opensuse.org
- Update to version 3.3.2:
  + Misc bugfixes.
  + New user documentation using Mallard.
  + Updated translations.
- Change pkgconfig(gnome-doc-utils) BuildRequires to yelp-tools,
  following the build system change for user documentation.
- Manually list the translated help documents as %%find_lang doesn't
  support the new XDG help system yet.
* Tue Nov  1 2011 dimstar@opensuse.org
- Initial package, version 3.3.1:
  + First release after the split of gnome-utils.
